# Generated by Django 3.0.5 on 2020-04-19 19:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_ddns', '0006_extradns_cname'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='zone',
            options={'ordering': ('name',), 'verbose_name': 'forward zone', 'verbose_name_plural': 'forward zones'},
        ),
    ]
