{% load render_table from django_tables2 %}

{% if perms.netbox_ddns.view_extradnsname %}
    <div class="card">
        <h5 class="card-header">Extra DNS Names</h5>

        <div class="card-body">
            {% render_table extra_dns_name_table 'inc/table.html' %}
        </div>

        {% if perms.netbox_ddns.add_extradnsname %}
            <div class="card-footer text-right noprint">
                <a href="{% url 'plugins:netbox_ddns:extradnsname_create' ipaddress_pk=object.pk %}"
                   class="btn btn-sm btn-primary">
                    <span class="mdi mdi-plus" aria-hidden="true"></span>Add extra DNS name
                </a>
            </div>
        {% endif %}
    </div>
{% endif %}
